#! /bin/csh
#-------------------------------------------------------------------------------
#
#     Name:   
#        af2_start
#
#     Invocation:
#        source af2_start
#
#     Description:
#        C-shell script for running af2 applications.  Sets up the path to
#        the standard reference files.
#
#     Arguments:
#        None
#
#     Language:
#        C-shell
#
#     Non-standard language extensions:
#        None
#
#     Algorithm:
#        -- If the environment variable WHT_AF2DATA_DIR is not defined, then
#           prompt for it.  Let the directory where this routine is located
#           be the default.
#        -- Add the STARLINK binary directory to the current path.
#
#     Authors:
#        (JRL): James R. Lewis -- RGO, Cambridge
#        (Greimel): Robert Greimel -- ING, La Palma
#
#     History:
#        01 Dec 1995 (JRL):
#           Original version
#        20 Feb 1996 (JRL):
#           Fixed bug which caused variable $data2 to be undefined under 
#           SunOS (NB: worked on Solaris and Alpha).
#        02 May 1996 (JRL):
#           Changed calls to dirname, basename, echo and pwd to use the full
#           pathname.  This should protect against people who have aliased
#           these functions.
#        06 Oct 2005 (Greimel):
#           Changed calls to dirname, basename, echo and pwd to NOT use the
#           pathname in order to improve portability. To protect against user
#           aliases these commands are called with \ to prevent the shell to
#           use alias substitution.
#
#-------------------------------------------------------------------------------

# Initialise the af2 status variable

set af2_status = 0

# If the environment variable WHT_AF2DATA_DIR is undefined, we need to prompt
# for it.  Follow all soft links until you find the original binary and
# set the default to the directory holding that executable image.

if (! $?WHT_AF2DATA_DIR) then
   set file = `\echo $0`
   set def = `\dirname $file`
   set stdir = `\pwd`
   set data1 = `\ls -l $file | awk '{print(substr($0,1,1))}'`
   set data2 = `\ls -l $file | awk '{print $NF}'`
   while ($data1 == 'l')
      cd `\dirname $data2`
      set def = `\pwd`
      set file = `\basename $data2`
      set data1 = `\ls -l $file | awk '{print(substr($0,1,1))}'`
      set data2 = `\ls -l $file | awk '{print $NF}'`
   end
   if ($def == "" || $def == ".") set def = `\pwd`
   cd $stdir
   unset file stdir data1 data2

# Prompt for an answer.  If the answer is blank then accept the default
# If the answer is '!!' then abort immediately.  If it is neither of these, 
# then use whatever was typed in, so long as the directory exists.

   echo -n "Define WHT_AF2DATA_DIR ($def) > "
   set ans = $<
   if ($ans ==  "") then
      setenv WHT_AF2DATA_DIR $def
   else if ($ans == '\!\!') then
      echo '***Abort requested***'
      set af2_status = 1
      goto exit
   else
      if (-e $ans && -d $ans) then
         setenv WHT_AF2DATA_DIR $ans
      else
         echo 'Requested directory does not exist'
         set af2_status = 1
         goto exit
      endif
   endif
   unset ans def
endif
echo "Taking standard telescope and fibre info from: "$WHT_AF2DATA_DIR

#  Put starlink bin directory at end of path, otherwise starlink PGPLOT 
#  won't work...God alone knows why...

if (`\echo ${PATH} | grep -c ':/star/bin'` == 0 && \
   `\echo ${PATH} | grep -c '^/star/bin'` == 0) then
   setenv PATH $PATH":/star/bin"
endif

exit:
