      program af2_hcopy
C+------------------------------------------------------------------------------
C     Name:   
C        af2_hcopy
C
C     Description:
C        Main routine for creating a hard copy of a pre-existing configuration
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        None
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, do while, variable names > 6 characters
C
C     Logical i/o units used:
C        53
C
C     External routines called:
C        Library subaf2_configure:
C           csub_getenv
C           getval_c
C           getval_i
C           getval_l
C           plotit
C           rdfibinfo
C           rdold
C           read_objects
C           telescopeinfo
C 
C        Library chr:
C           chr_len
C           chr_puti
C 
C        Library pgplot:
C           pgask
C           pgbeg
C           pgend
C           pgqinf
C 
C     Algorithm:
C       -- The telescope information and the field file (the file with
C          the coordinates of the objects to be allocated) is read in.
C          Then the file with the latest information on the fibre bundle
C          being used is read in.
C       -- If no configuration file exists for this field, then we are thrown
C          out.  If at least one exists, then the user is prompted as to which
C          one he/she/it wants to use.
C       -- The placement is plotted.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C        18 Sep 1996 (JRL):
C           Modified to remove some extraneous code
C
C-------------------------------------------------------------------------------
C
C     Global Parameters
C
      include 'AF2_PAR.INC'
      include 'AF2_FSTA.INC'
C
C     Local parameters
C
      integer fldfile
      parameter (fldfile=53)
C
C     Local variables
C
      integer status,len1,i,iostat,nold,len2,nobj,nfids,nsky
      integer otype(maxobj),sotype(maxobj),npivots,nguides,piv_r,park_r
      integer fibdims(3),fibstatus(nfibres),piv(2,nfibres)
      integer fib(2,nfibres),park(2,nfibres),allocated(nfibres)
      integer object_ref(maxobj),sky_ref(maxobj),n_obj_left,n_sky_left
      integer len3,nskip,nunused,length
      character dir*80,string*80,basename*80,cfgfile*80
      character ocfgfile*80,plog(maxobj)*80,slog(maxobj)*80
      character fibstring*80,label*80,fibrefile*80,value*3
      character temp1*10,temp2*10
      logical exist,verbose,whole,replace_pa,hush
      real scales(3),field_size,object(2,maxobj),skypos(2,maxobj)
      real weight(maxobj),sweight(maxobj),maxnonrad,fibrelen2,pgrad
      real pscale(2),new_pa
C
C     Functions
C
      integer chr_len,pgbeg
C
C     Common blocks
C
      common /scan/ replace_pa,new_pa,hush
C
C     Initialise the status variable
C
      status = af2_ok
C
C     Get the name of the directory where the "general" files are kept
C     These include the fibre information file and the telescope information
C     file. Make sure there is a / at the end of the string.  Note this will
C     only work for UNIX boxes.
C
      call csub_getenv('WHT_AF2DATA_DIR',dir,15,80,status)
      len1 = chr_len(dir)
      if (dir(len1:len1) .ne. '/') dir(len1+1:len1+1) = '/'
C
C     Get the parameters which map the telescope distortion from telescope
C     information file.
C
      call telescopeinfo(dir,field_size,scales,status)
      if (status .ne. af2_ok) go to 500
C
C     Get the input field file.  This should be a file with the extension
C     .fld, but strip this extension off if it does (it will be added back
C     in later).  Also, keep a copy of the base name which you will use 
C     as a base name for other files.  
C
      call getval_c('Input field file',' ',string,status)
      if (status .ne. af2_ok) go to 500
      len1 = chr_len(string)
      if (string(len1-3:len1) .eq. '.fld') len1 = len1 - 4
      basename = string(1:len1)
C
C     Add the .fld (always lower case!) extension and try to open the 
C     field file now
C
      string(len1+1:len1+4) = '.fld'
      len1 = len1 + 4
      write(*,fmt='(a,a)') 'Input field file is: ',string(:len1)
      open(unit=fldfile,file=string(:len1),status='old',
     :   access='sequential',iostat=iostat)
      if (iostat .ne. 0) then
         status = af2_err
         write(*,fmt='(a,a)') 'Error opening file: ',string(:len1)
         go to 500
      end if
C
C     Form the configure file name and see if there are any old versions
C     of this file lying around.  If there aren't then you can do no more.
C
      len1 = chr_len(basename)
      cfgfile = basename(:len1)//'.cfg.1'
      inquire(file=cfgfile(:len1+6),exist=exist)
      if (.not. exist) then
         write(*,fmt='(a,a)') 'No configuration file exists for field ',
     :      basename(:len1)
         go to 500
      end if
C
C     Find the latest version number of the configure file
C
      nold = maxver + 1
      exist = .false.
      do while (.not. exist)
         nold = nold - 1
         cfgfile = basename(:len1)//'.cfg.'
         len2 = len1 + 5
         call chr_puti(nold,cfgfile,len2)
         inquire(file=cfgfile(:len2),exist=exist)
      end do
C
C     Now prompt the user for the version number to use.  If there is only
C     one version, then use that one.
C
      if (nold .gt. 1) then
         len2 = 0
         call chr_puti(nold,temp1,len2)
         len3 = 0
         call chr_puti(nold,temp2,len3)
         call getval_i('Which version do you want to use?',
     :      temp1(:len2),'1',temp2(:len3),nold,status)
         if (status .ne. af2_ok) go to 500
      else
         nold = 1
      end if
C
C     Form old configuration file name
C
      ocfgfile = basename(:len1)//'.cfg.'
      len2 = len1 + 5
      call chr_puti(nold,ocfgfile,len2)
C
C     Read the field file.  This includes reading the header information
C     (UTDATE, HA, etc), reading the object information, converting the
C     RA,DEC to x,y and sorting the objects by types.  
C
      replace_pa = .false.
      hush = .false.
      verbose = .false.
      call read_objects(fldfile,0,0,verbose,scales,
     :   field_size,nobj,nfids,nsky,nskip,object,otype,skypos,
     :   sotype,plog,slog,weight,sweight,fibstring,label,status)
      if (status .ne. af2_ok) go to 500
      write(*,fmt='(a)') ' '
      write(*,fmt='(i3,a)') nfids,' fiducial objects'
      write(*,fmt='(i3,a)') nobj-nfids,' program objects'
      write(*,fmt='(i3,a)') nsky,' sky positions'
      write(*,fmt='(i3,a)') nskip,' objects outside of field'
      write(*,fmt='(a)') ' '
C
C     Form the name of the fibre information file from the name of the fibre
C     bundle as it was read in the header of the field file. The name of
C     the fibre information file is (always in lower case) the name of the
C     bundle with the string '_fibres.dat' appended.  Don't forget the
C     name of the directory as well
C
      len1 = chr_len(fibstring)
      len2 = chr_len(dir)
      fibrefile = dir(:len2)//fibstring(:len1)//'_fibres.dat'
      len1 = len1 + len2 + 11
C
C     See if the fibre info file exists.  If it doesn't, then signal
C     an error
C
      inquire(file=fibrefile(:len1),exist=exist)
      if (.not. exist) then
         write(*,fmt='(a,a,a)') 'The file ',fibrefile(:len1),
     :      ' does not exist'
         write(*,fmt='(a)')
     :      'Do you have the correct bundle name in field file?'
         status = af2_err
         go to 500
      end if
C
C     Read the fibre information.  This includes the number of pivots,
C     the number of guide fibres, the maximum non-radial angle the fibres
C     can subtend, the square of the fibre length, the dimensions of the
C     fibre tubing and button, the pivot and park radii, the status of
C     each fibre (whether it's disabled, etc), the pivot locations,
C     the current button locations and the park locations.
C
      call rdfibinfo(fibrefile,1.0,npivots,nguides,nunused,maxnonrad,
     :   fibrelen2,fibdims,piv_r,park_r,fibstatus,piv,fib,park,status)
      if (status .ne. af2_ok) go to 500
C
C     Initialise the fibre allocation record.  These will eventually 
C     say to which object a specific fibre has been allocated.  If the
C     value is zero, then the fibre is unallocated and available.  If the value
C     is negative then there is something wrong.  The fibre status 
C     (fibstatus) and the allocation record (allocated) can assume the 
C     following values initially.
C
C        fibstatus          allocated       comment
C        ------------------------------------------------------------------
C        fsta_miss            -30           Missing fibre
C        fsta_ook               0           Normal object fibre
C        fsta_fok               0           Normal guide fibre
C        fsta_odis            -10           Disabled object fibre
C        fsta_fdis            -10           Disabled guide fibre
C        fsta_odead           -20           Dead object fibre
C        fsta_fdead           -20           Dead guide fibre
C
C     Later when the fibre allocation has been done, the fibres which
C     started with values of 0 can have the reference number of an object 
C     or sky patch.  
C
      do 20 i = 1,npivots
         if ((fibstatus(i) .eq. fsta_ook) .or. 
     :      (fibstatus(i) .eq. fsta_fok)) then
            allocated(i) = 0
         else if ((fibstatus(i) .eq. fsta_odis) .or. 
     :      (fibstatus(i) .eq. fsta_fdis)) then
            allocated(i) = -10
         else if ((fibstatus(i) .eq. fsta_odead) .or. 
     :      (fibstatus(i) .eq. fsta_fdead)) then
            allocated(i) = -20
         else if (fibstatus(i) .eq. fsta_miss) then
            allocated(i) = -30
         end if
  20  continue
C
C     The array object_ref contains the number of each object.  Initially
C     this is just the number 1,2,3...nobj.  But this array will be 
C     swapped around a lot, so referencing object information won't be 
C     quite so trivial.  Do the same for the sky patches.  
C
      do 30 i = 1,nobj
         object_ref(i) = i
  30  continue
      do 40 i = 1,nsky
         sky_ref(i) = i
  40  continue
C
C     The variables n_obj_left and n_sky_left denote the number of objects
C     and skies which haven't yet been covered by a fibre.  We initialise them
C     to the number of objects and skies read in the field file.
C
      n_obj_left = nobj
      n_sky_left = nsky
C
C     Read the old configuration file.
C
      call rdold(ocfgfile,npivots,fibstatus,verbose,fib,piv,
     :   allocated,object_ref,object,skypos,n_obj_left,n_sky_left,
     :   sky_ref,plog,slog,fibrelen2,maxnonrad,fibdims,status)
      if (status .ne. af2_ok) go to 500
C
C     Open the graphics device.  If it isn't a hard device, then signal an
C     error and escape
C
      if (pgbeg(0,'?',1,1) .ne. 1) go to 500
      call pgqinf('hardcopy',value,length)
      if (length .eq. 2) then
         write(*,fmt='(a)')
     :      'Requested PGPLOT device is not a hard device!'
         call pgend
         go to 500
      end if
C
C     Set up scaling factors for plot.  Ask if the user wants to see the
C     whole of the fibre plate (all the way out to the pivot circle).  
C     Usually that won't be necessary.
C
      call pgask(.false.)
      pscale(1) = 1.0
      pscale(2) = 1.0
      call getval_l('Show whole plate?','no',whole,status)
      if (status .ne. af2_ok) go to 500
      if (whole) then
         pgrad = piv_r
      else
         pgrad = 1.1*park_r
      end if
C
C     Do the plot and close it up.
C
      call plotit(piv_r,field_size,nobj,object,npivots,park,pgrad,otype,
     :   fibstatus,nsky,skypos,.true.,.true.,pscale,piv,fib,fibdims,
     :   .true.,label,status)
      call pgend
C
C     Close up the input field file
C
      close(fldfile)
C
C     Exit
C
  500 continue
      end
