#include <stdio.h>
#include <stdlib.h>
#include "af2_par.h"

void csub_malloc__(size,ptr,status)
/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Name:                                                                   */
/*       csub_malloc_                                                         */
/*                                                                            */
/*    Invocation:                                                             */
/*       call csub_malloc(size,ptr,status)                                    */
/*                                                                            */
/*    Description:                                                            */
/*       Allocate a designated amount of workspace. This is meant to be       */
/*       called from a FORTRAN routine.                                       */
/*                                                                            */
/*    Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)         */
/*       size:  Int* (>)                                                      */
/*          The size of the workspace to be allocated in bytes                */
/*       ptr:  Unsigned int* (<)                                              */
/*          The pointer to the workspace to be freed                          */
/*       status:  Int* (!)                                                    */
/*          The global status variable                                        */
/*                                                                            */
/*    Language:                                                               */
/*       ANSI C                                                               */
/*                                                                            */
/*    Non-standard language extensions:                                       */
/*       None                                                                 */
/*                                                                            */
/*    Algorithm:                                                              */
/*       -- Allocate the workspace using the standard C intrinsic routine     */
/*                                                                            */
/*    Authors:                                                                */
/*       (JRL): James R. Lewis -- RGO, Cambridge                              */
/*                                                                            */
/*    History:                                                                */
/*       01 Dec 1995 (JRL):                                                   */
/*          Original version                                                  */
/*                                                                            */
/*----------------------------------------------------------------------------*/

/* Parameters */
int *const size;
unsigned int *const ptr;
int *const status;

{

      /* Local variables*/      
      void *temp;

      /* Inherited status */
      if (*status != AF2_OK) return;

      /* Attempt to allocate the workspace */
      temp = malloc((size_t)(*size)) ;

      /* If the allocation was ok (e.g. the null pointer wasn't returned)
         then put the pointer to the return variable.  Otherwise signal
         an error */
      if (temp != 0) {
         *ptr = (unsigned int)temp;
      } else {
         fprintf(stderr,"Could not allocate %d bytes of space\n",*size);
         *status = AF2_ERR;
      }
}
