      subroutine graphmsg(line,string,ci,pscale)
C+------------------------------------------------------------------------------
C
C     Name:   
C        graphmsg
C
C     Invocation:
C        call graphmsg(line,string,ci,pscale)
C
C     Description:
C        Write a message into the message box in the PGPLOT window.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        line:  Integer (>)
C           The line on which to start the message.
C        string:  Character (>)
C           The message string.
C        ci:  Integer (>)
C           The PGPLOT colour index for the text
C        pscale:  Real array (>)
C           Plot scaling factors: 1 -- the linear scale, 2 -- the text height
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, do while, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library chr:
C           chr_len
C
C        Library pgplot:
C           pgqvp
C           pgqwin
C           pgrect
C           pgsci
C           pgsfs
C           pgtext
C           pgvport
C           pgwindow
C 
C     Algorithm:
C        -- Get a copy of the window and viewport limits
C        -- The the viewport to the location of the message window and
C           give it a world coordinate range of 0 to 1 in both x and y
C        -- If 'line' is negative, then you are putting the text on the
C           next available line.  Otherwise calculate the message location
C           and clear the message box beneath it.
C        -- Write out the string on the given line, breaking it if necessary.
C        -- Return the viewport and window to their input settings and reset
C           the colour index to the drawing colour.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Parameters
C
      integer line
      character string*(*)
      integer ci
      real pscale(2)
C
C     Local parameters
C
      real space
      parameter (space=0.07)
      integer maxchars
      parameter (maxchars=34)
C
C     Local variables
C
      real plotlim(4),vlim(4),ymsg,space2
      integer len1,start,end
C
C     Functions
C
      integer chr_len
C
C     Common blocks
C
      common /msgloc/ ymsg,space2
C
C     Make a copy of the space between lines for common block
C
      space2 = space
C
C     First store away the main window information
C
      call pgqwin(plotlim(1),plotlim(2),plotlim(3),plotlim(4))
      call pgqvp(0,vlim(1),vlim(2),vlim(3),vlim(4))
C
C     Set to the sub-window where the messages should be written
C
      call pgvport(0.0,0.35*pscale(1),0.0,0.42)
      call pgwindow(0.0,1.0,0.0,1.0)
C
C     If 'line' is negative, then we are appending the message 
C     to whatever is already there.   So, if 'line' is positive then
C     we need to clear the square at that line and below.
C
      if (line .gt. 0) then
         ymsg = 1.0 - real(line)*space
         call pgsfs(1)
         call pgsci(0)
         call pgrect(0.05,0.94,0.05,ymsg+space)
      end if
C
C     If the location of the message (in y) is below the box, then
C     clear the box and send the message up to the top of it
C
      if (ymsg .lt. 0.05) then
         ymsg = 1.0 - space
         call pgsfs(1)
         call pgsci(0)
         call pgrect(0.05,0.94,0.05,ymsg)
      end if
C
C     Set the colour index to the one requested and get the length of
C     the output string
C
      call pgsci(ci)
      len1 = chr_len(string)
C
C     Now write out the string, breaking it if necessary. 
C
      start = 1
      end = 0
      do while (end .lt. len1)
C
C        Find the first non-white character
C
         do while (string(start:start) .eq. ' ')
            start = start + 1
         end do
C
C        Now add on the maximum number of characters and count
C        back until you find a space.
C
         end = min(start+maxchars-1,len1)
         if (end .ne. len1) then
            do while ((string(end:end) .ne. ' ') .and. (end .gt. start))
               end = end - 1
            end do
            if (end .eq. start) end = min(start+maxchars-1,len1)
         end if
C
C        Now write it out.
C
         call pgtext(0.05,ymsg,string(start:end))
C
C        Increment the y location for the next line and the starting
C        point for the next output string
C
         ymsg = ymsg - space
         start = end + 1
      end do
C
C     Return the window settings to what they were before we started this
C     routine.  Also reset the colour index to the drawing colour.
C
      call pgvport(vlim(1),vlim(2),vlim(3),vlim(4))
      call pgwindow(plotlim(1),plotlim(2),plotlim(3),plotlim(4))
      call pgsci(1)
C
C     Exit
C
      end
