      subroutine readreal(fd,nread,value,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        readreal
C
C     Invocation:
C        call readreal(fd,nread,value,status)
C
C     Description:
C        Read a real value from first word of a line of a file
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        fd:  Integer (>)
C           Logical unit of the fibre information file
C        nread:  Integer(!)
C           The number of lines read in the file so far
C        value:  real (<)
C           The output value
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library chr:
C           chr_ctor
C           chr_dcwrd
C           chr_len
C 
C     Algorithm:
C        -- Read a line of data from the file.  Send an error message if
C           the end of file is reached.
C        -- Decode the first word of the string into a real.  Send an
C           error message if this doesn't work.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer fd
      integer nread
      integer status
      real value
C
C     Local variables
C
      character string*80,word*40,fname*80
      integer n,start(1),stop(1),ignore,len1,iostat
C
C     Functions
C
      integer chr_len
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Read a string and check for errors
C
      read(unit=fd,fmt='(a)',iostat=iostat) string
      nread = nread + 1
      if (iostat .ne. 0) then
         inquire(fd,name=fname)
         len1 = chr_len(fname)   
         write(*,'(a,i3,a,a)') 'Error reading line ',nread,
     :      ' of ',fname(:len1)
         status = af2_err
         go to 500
      end if
C
C     Decode the first word of the string into a real and check for errors
C
      call chr_dcwrd(string,1,n,start,stop,word,ignore)
      call chr_ctor(word,value,status)
      if (status .ne. af2_ok) then
         inquire(fd,name=fname)
         len1 = chr_len(fname)   
         write(*,'(a,i3,a,a)') 'Error reading real value from line ',
     :      nread,' of ',fname(:len1)
      end if
C
C     Exit
C
  500 continue
      end
