      subroutine remove_from_list(object_ref,n_obj_left,sky_ref,
     :   n_sky_left,id)
C+------------------------------------------------------------------------------
C
C     Name:   
C        remove_from_list
C
C     Invocation:
C        call remove_from_list(object_ref,n_obj_left,sky_ref,n_sky_left,id)
C
C     Description:
C        An object is removed either from the object reference or the sky
C        reference list.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        object_ref:  Integer array (!)
C           The list of reference numbers of objects which have not 
C           been allocated to a fibre.
C        n_obj_left:  Integer (!)
C           The number of objects which have not yet been allocated.
C        sky_ref:  Integer array (!)
C           The list of reference numbers of the sky patches which have
C           not been allocated to a fibre
C        n_sky_left:  Integer (!)
C           The number of sky patches which have not yet been allocated
C        id:  Integer (>)
C           The reference number of the object to be removed.  If this is
C           a sky patch, this should include the sky offset.
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        none
C 
C     Algorithm:
C        -- If the input reference number is not in the allowed range, then
C           exit this routine immediately.
C        -- If the input reference number is less than the sky offset, then
C           loop through the object reference list and find it.  Remove it
C           by replacing it with the last object from the reference list and
C           decrementing the total number of unallocated objects.
C        -- If the input reference number is greater than the sky offset, then
C           do a similar loop through the sky reference list. 
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer object_ref(*)
      integer n_obj_left
      integer sky_ref(*)
      integer n_sky_left
      integer id
C
C     Local variables
C
      integer i
C
C     If the input object reference number <= 0 (fibre is parked) or
C     the object is a cursor placed sky position then exit immediately
C
      if ((id .le. 0) .or. (id .ge. alloc_cur)) go to 500
C
C     If this is an object then search through the object reference
C     list.  Move the last object in the object reference list to the
C     location of the object you wish to remove.  If the object wasn't
C     found, then send out an error message. (This is not a serious error)
C
      if (id .lt. alloc_sky) then
         do 10 i = 1,n_obj_left
            if (id .eq. object_ref(i)) then
               object_ref(i) = object_ref(n_obj_left)
               object_ref(n_obj_left) = 0
               n_obj_left = n_obj_left - 1
               go to 500
            end if
  10     continue
         write(*,fmt='(a)')
     :      'Could not delete object from list'
C
C     Otherwise, this is a sky patch and remove it from the sky
C     reference list.
C
      else 
         do 20 i = 1,n_sky_left
            if (id - alloc_sky .eq. sky_ref(i)) then
               sky_ref(i) = sky_ref(n_sky_left)
               sky_ref(n_sky_left) = 0
               n_sky_left = n_sky_left - 1
               go to 500
            end if
  20     continue
         write(*,fmt='(a)')
     :      'Could not delete sky position from list'
      end if
C
C     Exit
C
  500 continue
      end
