      subroutine rep_pl(npivots,allocated,fibstatus,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        rep_pl
C
C     Invocation:
C        call rep_pl(npivots,allocated,fibstatus,status)
C
C     Description:
C        Report the number of objects placed according to type.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        npivots:  Integer (>)
C           The total number of pivots
C        allocated:  Integer array (>)
C           The reference number of the object which has been allocated
C           to a particular fibre.
C        fibstatus:  Integer array (>)
C           The fibre status (i.e. whether it's useable, disabled etc.)
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library subaf2_configure:
C           count_pl
C 
C     Algorithm:
C        -- Count the number of objects placed by type (program, fiducial,
C           sky, cursor)
C        -- Send out a nice message reporting the results.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer npivots
      integer allocated(npivots)
      integer fibstatus(npivots)
      integer status
C
C     Local variables
C
      integer nsp,nop,nfp,ncp
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     First count the number of each type of object
C
      call count_pl(npivots,allocated,fibstatus,nop,nsp,nfp,ncp)
C
C     Report on each type of object
C
      if (nop .ge. 0) 
     :   write(*,fmt='(i3,a)') nop,' program objects placed'
      if (nfp .ge. 0)
     :   write(*,fmt='(i3,a)') nfp,' fiducial objects placed'
      if (nsp .ge. 0) 
     :   write(*,fmt='(i3,a)') nsp,' sky fibres placed'
      if (ncp .ge. 0)
     :   write(*,fmt='(i3,a)') ncp,' placed by cursor only'
C
C     Exit
C
  500 continue
      end
