      subroutine xyout(npivots,fib,fibfile,extn,fibstring,
     :   nguides,nunused,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        xyout
C
C     Invocation:
C        call xyout(npivots,fib,fibfile,extn,fibstring,nguides,
C           nunused,status)
C
C     Description:
C        The x,y positions of all of the fibres are written out to a file.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        npivots:  Integer (>)
C           The total number of pivots
C        fib:  Integer array (>)
C           The current x,y position of each fibre button
C        fibfile:  Character (>)
C           The name of the file to send the x,y information to
C        extn:  Character (>)
C           The x,y file extension
C        fibstring:  Character (>)
C           The name of the fibre bundle
C        nguides:  Integer (>)
C           The total number of guide fibres
C        nunused:  Integer (>)
C           The total number of unused fibres
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        41
C
C     External routines called:
C        Library subaf2_configure:
C           opnewfile
C 
C        Library chr:
C           chr_len
C           chr_ucase
C 
C     Algorithm:
C        -- Open the new file and write the fibre name, the number of
C           pivots, the number of guides and the number of unused fibres 
C           to it.
C        -- For each pivot, write the current x,y of the associated fibre
C           to the file
C        -- Close the file
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer npivots
      integer fib(2,npivots)
      character fibfile*(*)
      character extn*(*)
      character fibstring*(*)
      integer nguides
      integer nunused
      integer status
C
C     Local parameters
C 
      integer fd
      parameter (fd=41)
C
C     Local variables
C
      integer i,len1
      character fibstring2*80
C
C     Functions
C
      integer chr_len
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Open fibre xy file for output
C
      call opnewfile(fibfile,extn,fd,.true.,status)
      if (status .ne. af2_ok) go to 500
C
C     Convert the bundle name to upper case and write it to the xy file.
C
      fibstring2 = fibstring
      call chr_ucase(fibstring2)
      len1 = chr_len(fibstring2)
      write(fd,fmt='(a)') fibstring2(:len1)
C
C     Write the number of pivots, the number of guide fibres and the number
C     of unused guide fibres to the file...
C
      write(fd,fmt='(i3)') npivots
      write(fd,fmt='(i3)') nguides
      write(fd,fmt='(i3)') nunused
C
C     For each pivot, write its number and xy position
C
      do 10 i = 1, npivots
         write (fd,fmt='(i4,2i9)') i,fib(1,i),fib(2,i)
  10  continue
C
C     Close up the file
C
      close(fd)
C
C     Exit
C
  500 continue
      end
